export interface IPublicProps {
    dashboardId: string;
    chartId?: string;
    authKey?: string;
    authToken?: string;
    language?: string;
    screenmode?: ScreenMode;
    switchScreenModeOnResize?: boolean;
    loaderBackground?: string;
    loaderFontColor?: string;
    loaderSpinnerColor?: string;
    loaderSpinnerBackground?: string;
    loaderLogoColor?: string;
    debug?: boolean;
}
export interface ICssStyles {
    loaderSize: number;
    borderWidth: number;
    minHeight: number | string;
}
export declare enum ScreenMode {
    MOBILE = "mobile",
    TABLET = "tablet",
    DESKTOP = "desktop",
    LARGE_SCREEN = "largeScreen",
    FIXED = "fixed",
    AUTO = "auto"
}
export interface IError {
    message?: string;
    displayableMessage?: string;
}
export declare const breakpoints: {
    mobile: number[];
    tablet: number[];
    desktop: number[];
    largeScreen: number[];
    fixed: any[];
};
export declare enum MessageTypes {
    INIT = "init",
    CHANGED_FILTERS = "changedFilters",
    DATA = "data",
    LOAD = "load",
    ERROR = "error",
    EXPORT = "export",
    CHARTS_RENDERED = "chartsRendered"
}
export interface IDashboardFilterParameter {
    column_id: string;
    dataset_id: string;
}
export interface IDashboardPropertiesParameter {
    id: string;
    viz: string;
    origin: string;
    type: string;
}
export interface IDashboardFilter {
    parameters?: IDashboardFilterParameter[];
    properties?: IDashboardPropertiesParameter;
    expression?: string;
    column_id?: string;
    value?: string;
}
export interface IDashboardParsedFilter {
    expression: string;
    columnId: string;
    datasetId: string;
    chartId: string;
    value: string;
}
export interface IDashboardFilters {
    dashboardId: string;
    activeFilters: IDashboardParsedFilter[];
}
export interface IAvailableScreenmode {
    width: number[];
    height: number[];
    mode: string;
}
export declare const Translations: {
    initializing: {
        en: string;
        nl: string;
        fr: string;
    };
    errorDashboard: {
        en: string;
        nl: string;
        fr: string;
    };
    errorChart: {
        en: string;
        nl: string;
        fr: string;
    };
};
